pychemia.code.octopus package
=============================

.. automodule:: pychemia.code.octopus
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

pychemia.code.octopus.analysis module
-------------------------------------

.. automodule:: pychemia.code.octopus.analysis
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.code.octopus.input module
----------------------------------

.. automodule:: pychemia.code.octopus.input
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.code.octopus.merge module
----------------------------------

.. automodule:: pychemia.code.octopus.merge
    :members:
    :undoc-members:
    :show-inheritance:


